The Mallgroup library is a collection of utilities.

To install mallgroup_python_lib along with the tools
you need to develop and run tests, run the following
in your virtualenv:

```bash
$ pip install -e .[dev]
```

Utilities:
Heartbeat

Contact:
dataengineering@mallgroup.com

Authors:
Pressl Dan
Urban Aemilia
